@@ -10,8 +10,6 @@ class GameConfig:
     def __init__(self, argv):
         self.app_dir = Path(os.path.abspath(os.path.dirname(__file__))).parent
 
-        self.context_path = os.getenv("CONTEXT_PATH") or self.app_dir
-
         self.data_dir = self.make_data_dir()
 
         opts, _args = getopt(
@@ -83,7 +81,9 @@ class GameConfig:
         sys.exit()
 
     def make_data_dir(self):
-        data_dir_path = os.path.join(self.context_path, "fantomatic_data")
+        data_env = os.getenv("DATA_DIR") or self.app_dir
+
+        data_dir_path = os.path.join(self.data_dir, "fantomatic_data")
         if not os.path.isdir(data_dir_path):
             os.mkdir(data_dir_path)
         return data_dir_path
